// Copyright(C) 1999-2023 National Technology & Engineering Solutions
// of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
// NTESS, the U.S. Government retains certain rights in this software.
//
// See packages/seacas/LICENSE for details
#pragma once
#include <array>
#include <string>

static const std::array<std::string, 3> qainfo{
    "slice",
    "2023/09/14",
    "2.1.05",
};
